searchNodes=[{"doc":"defmodule Query do use Yesql, driver: Postgrex, conn: MyApp.ConnectionPool Yesql.defquery(&quot;some/where/select_users_by_country.sql&quot;) end Query.users_by_country(country_code: &quot;gbr&quot;) # =&gt; {:ok, [%{name: &quot;Louis&quot;, country_code: &quot;gbr&quot;}]}Supported driversPostgrexEcto, for which conn is an Ecto repo.ConfigurationCheckout the Postgrex or Ecto configuration guides.","ref":"Yesql.html","title":"Yesql","type":"module"},{"doc":"","ref":"Yesql.html#defquery/2","title":"Yesql.defquery/2","type":"macro"},{"doc":"YesqlYesql is an Elixir library for using SQL.","ref":"readme.html","title":"Yesql","type":"extras"},{"doc":"You're writing Elixir You need to write some SQL.One option is to use Ecto, which provides a sophisticated DSL for generating database queries at runtime. This can be convenient for simple use, but its abstraction only works with the simplest and common database features. Because of this either the abstraction breaks down and we start passing raw strings to Repo.query and fragment, or we will neglect these database features altogether.So what's the solution? Keep the SQL as SQL. Have one file with your query:SELECT * FROM users WHERE country_code = :country_code...and then read that file to turn it into a regular Elixir function at compile time:defmodule Query do use Yesql, driver: Postgrex, conn: MyApp.ConnectionPool Yesql.defquery(&quot;some/where/select_users_by_country.sql&quot;) end # A function with the name `users_by_country/1` has been created. # Let&#39;s use it: iex&gt; Query.users_by_country(country_code: &quot;gbr&quot;) {:ok, [%{name: &quot;Louis&quot;, country_code: &quot;gbr&quot;}]}By keeping the SQL and Elixir separate you get:No syntactic surprises. Your database doesn't stick to the SQL standard - none of them do - but Yesql doesn't care. You will never spend time hunting for &quot;the equivalent Ecto syntax&quot;. You will never need to fall back to a fragment(&quot;some('funky'::SYNTAX)&quot;) function.Better editor support. Your editor probably already has great SQL support. By keeping the SQL as SQL, you get to use it.Team interoperability. DBAs and developers less familiar with Ecto can read and write the SQL you use in your Elixir project.Easier performance tuning. Need to EXPLAIN that query plan? It's much easier when your query is ordinary SQL.Query reuse. Drop the same SQL files into other projects, because they're just plain ol' SQL. Share them as a submodule.Simplicity. This is a very small library, it is easier to understand and review than Ecto and similar.When Should I Not Use Yesql?When you need your SQL to work with many different kinds of database at once. If you want one complex query to be transparently translated into different dialects for MySQL, Oracle, Postgres etc., then you genuinely do need an abstraction layer on top of SQL.","ref":"readme.html#rationale","title":"Yesql - Rationale","type":"extras"},{"doc":"We've talked about Ecto, but how does Yesql compare to $OTHER_LIBRARY?eqleql is an Erlang library with similar inspiration and goals.eql offers no solution for query execution, the library user has to implement this. Yesql offers a friendly API.Being an Erlang library eql has to compile the queries at runtime, Yesql does this at compile time so you don't need to write initialisation code and store your queries somewhere.eql requires the neotoma PEG compiler plugin, Yesql only uses the Elixir standard library.Yesql uses prepared statements so query parameters are sanitised and are only valid in positions that your database will accept parameters. eql functions more like a templating tool so parameters can be used in any position and sanitisation is left up to the user.A subjective point, but I believe the Yesql's implementation is simpler than eql's, while offering more features.ayesqlayesql is another Elixir library, a bit more powerful than yesql:It offers support for various SQL statements in a single file.Special constructs for query composability in SQL files.Special constructs for optional parameters in SQL files.yesql will keep your SQL queries closer to canonical SQL, but if you start finding it limiting or convoluted maybe it would be a good time to check out more powerful abstractions like ayesql or Ecto.","ref":"readme.html#alternatives","title":"Yesql - Alternatives","type":"extras"},{"doc":"createdb yesql_test mix deps.get mix test","ref":"readme.html#development-testing","title":"Yesql - Development &amp; Testing","type":"extras"},{"doc":"Yesql rips off is inspired by Kris Jenkins' Clojure Yesql. Similar libraries can be found for many languages:LanguageProjectC#JaSqlClojureYeSPARQLClojureYesqlElixirayesqlErlangeqlGoDotSqlGogoyesqlJavaScriptPreqlJavaScriptsqltPHPYepSQLPythonAnosqlRubyyayql","ref":"readme.html#other-languages","title":"Yesql - Other Languages","type":"extras"},{"doc":"Copyright © 2018 Louis Pilfold. All Rights Reserved.","ref":"readme.html#license","title":"Yesql - License","type":"extras"},{"doc":"Ecto","ref":"ecto_configuration.html","title":"Ecto","type":"extras"},{"doc":"We only need the postgrex and ecto_sql dependencies, but it doesn't hurt to also add ecto:defp deps do [ {:postgrex, &quot;~&gt; 0.15.4&quot;}, {:ecto_sql, &quot;~&gt; 3.4&quot;}, {:ecto, &quot;~&gt; 3.4&quot;}, {:yesql, &quot;~&gt; 1.0&quot;} ] end","ref":"ecto_configuration.html#install-dependencies","title":"Ecto - Install dependencies","type":"extras"},{"doc":"At the ecto docs we can find an excellent configuration guide for adding ecto to your project.First we declare our Repo module:defmodule Repo do use Ecto.Repo, otp_app: :my_app, adapter: Ecto.Adapters.Postgres endAnd add it to our supervision tree:defmodule MyApp.Application do use Application def start(_type, _args) do conn_params = [ name: MyApp.Repo, hostname: &quot;host&quot;, username: &quot;user&quot;, password: &quot;pass&quot;, database: &quot;your_db&quot; ] children = [ {Repo, conn_params}, ] Supervisor.start_link(children, [strategy: :one_for_one]) end end","ref":"ecto_configuration.html#start-ecto-process","title":"Ecto - Start ecto process","type":"extras"},{"doc":"Then declare your yesql module by specifying you want to use ecto along with the ecto process:defmodule Query do use Yesql, driver: Ecto, conn: MyApp.Repo Yesql.defquery(&quot;some/where/now.sql&quot;) Yesql.defquery(&quot;some/where/select_users.sql&quot;) Yesql.defquery(&quot;some/where/select_users_by_country.sql&quot;) end Query.now [] # =&gt; {:ok, [%{now: ~U[2020-05-09 21:22:54.680122Z]}]} Query.users_by_country(country_code: &quot;gbr&quot;) # =&gt; {:ok, [%{name: &quot;Louis&quot;, country_code: &quot;gbr&quot;}]}","ref":"ecto_configuration.html#declare-in-yesql","title":"Ecto - Declare in yesql","type":"extras"},{"doc":"Postgrex","ref":"postgrex_configuration.html","title":"Postgrex","type":"extras"},{"doc":"Add both dependencies in your mix.exs file: defp deps do [ {:postgrex, &quot;~&gt; 0.15.4&quot;}, {:yesql, &quot;~&gt; 1.0&quot;} ] end","ref":"postgrex_configuration.html#install-dependencies","title":"Postgrex - Install dependencies","type":"extras"},{"doc":"Althought it cna be started manually, it is a good idea to declare this process inside a supervision tree along with a name we can easily reference later.defmodule MyApp.Application do use Application def start(_type, _args) do conn_params = [ name: ConnectionPool, hostname: &quot;host&quot;, username: &quot;user&quot;, password: &quot;pass&quot;, database: &quot;your_db&quot; ] children = [ {Postgrex, conn_params}, ] Supervisor.start_link(children, [strategy: :one_for_one]) end end","ref":"postgrex_configuration.html#start-postgrex-process","title":"Postgrex - Start postgrex process","type":"extras"},{"doc":"Then declare your yesql module by specifying you want to use postgrex along with the postgrex process: defmodule Query do use Yesql, driver: Postgrex, conn: ConnectionPool Yesql.defquery(&quot;some/where/now.sql&quot;) Yesql.defquery(&quot;some/where/select_users.sql&quot;) Yesql.defquery(&quot;some/where/select_users_by_country.sql&quot;) end Query.now [] # =&gt; {:ok, [%{now: ~U[2020-05-09 21:22:54.680122Z]}]} Query.users_by_country(country_code: &quot;gbr&quot;) # =&gt; {:ok, [%{name: &quot;Louis&quot;, country_code: &quot;gbr&quot;}]}","ref":"postgrex_configuration.html#declare-in-yesql","title":"Postgrex - Declare in yesql","type":"extras"}]